AppendMessage

Struct AppendMessage 

#[non_exhaustive]
pub struct AppendMessage { pub flags: Vec<Flag>, pub date: Option<String>, pub data: Vec<u8>, }
A message to be appended via MULTIAPPEND (RFC 3502).

Each message carries its own flags, optional internal date, and raw message data. Multiple AppendMessage values are sent in a single APPEND command per RFC 3502 Section 3.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
flags: Vec<Flag>

Flags to set on the appended message (RFC 3501 Section 6.3.11).

date: Option<String>

Optional INTERNALDATE in IMAP date-time format (RFC 3501 Section 6.3.11).

data: Vec<u8>

Raw RFC 5322 message data.

Implementations

Source

impl AppendMessage

pub fn new(data: impl Into<Vec<u8>>) -> Self

Create an append message with only the raw data (RFC 3501 Section 6.3.11).

Flags default to empty and date defaults to None.