#[non_exhaustive]pub struct BodySection {
pub section: String,
pub origin: Option<u64>,
pub data: Option<Vec<u8>>,
}Expand description
A single fetched body section (RFC 3501 Section 6.4.5).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.section: StringThe section specification (e.g. "HEADER", "1.2", "TEXT").
origin: Option<u64>Byte offset if this was a partial fetch (<origin.count>).
RFC 9051 Section 7.5.2 widens this from number (u32) to number64 (u64)
to support messages > 4 GiB.
data: Option<Vec<u8>>The raw body data, or None if the server returned NIL.