NamespaceResponse

Struct NamespaceResponse 

#[non_exhaustive]
pub struct NamespaceResponse { pub personal: Vec<NamespaceDescriptor>, pub other: Vec<NamespaceDescriptor>, pub shared: Vec<NamespaceDescriptor>, }
Result of a NAMESPACE command (RFC 2342 Section 5).

Groups the three namespace categories into named fields instead of a positional tuple, making it safe to extend in the future.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
personal: Vec<NamespaceDescriptor>

Personal namespaces (RFC 2342 Section 5).

other: Vec<NamespaceDescriptor>

Other users’ namespaces (RFC 2342 Section 5).

shared: Vec<NamespaceDescriptor>

Shared namespaces (RFC 2342 Section 5).