#[non_exhaustive]pub struct NotifyEventGroup {
pub filter: MailboxFilter,
pub events: Vec<NotifyEvent>,
}Expand description
A group of events to monitor on a set of mailboxes (RFC 5465 Section 8).
RFC 5465 Section 8 ABNF:
event-group = "(" filter-mailboxes SP events ")"
events = ("(" event *(SP event) ")") / "NONE"Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.filter: MailboxFilterWhich mailboxes this event group applies to (RFC 5465 Section 6).
events: Vec<NotifyEvent>Events to monitor. An empty Vec means NONE — no events for this
filter (RFC 5465 Section 8).
Implementations
Sourceimpl NotifyEventGroup
impl NotifyEventGroup
Sourcepub fn new(filter: MailboxFilter, events: Vec<NotifyEvent>) -> Self
pub fn new(filter: MailboxFilter, events: Vec<NotifyEvent>) -> Self
Create a new event group for the given mailbox filter and events (RFC 5465 Section 8).