#[non_exhaustive]pub struct NotifySetParams {
pub status: bool,
pub event_groups: Vec<NotifyEventGroup>,
}Expand description
Parameters for the NOTIFY SET command (RFC 5465 Section 3).
RFC 5465 Section 8 ABNF:
notify = "NOTIFY" SP (notify-set / notify-none)
notify-set = "SET" [status-indicator] SP event-groupsFields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status: boolWhen true, the server sends an initial STATUS response for each
non-selected mailbox with message events before the tagged OK
(RFC 5465 Section 4, status-indicator = SP "STATUS").
event_groups: Vec<NotifyEventGroup>One or more event groups defining which events to monitor on which mailboxes (RFC 5465 Section 3).
Implementations
Sourceimpl NotifySetParams
impl NotifySetParams
Sourcepub fn new(event_groups: Vec<NotifyEventGroup>, status: bool) -> Self
pub fn new(event_groups: Vec<NotifyEventGroup>, status: bool) -> Self
Create NOTIFY SET parameters with the given event groups (RFC 5465 Section 3).
status controls whether the server sends initial STATUS responses
for non-selected mailboxes before the tagged OK (RFC 5465 Section 4).