#[non_exhaustive]pub struct ThreadNode {
pub id: Option<u32>,
pub children: Vec<Self>,
}Expand description
A node in a THREAD response tree (RFC 5256 Section 4).
Each node represents a message in a thread. A dummy parent (id == None)
is used when the threading algorithm infers a parent that does not
correspond to an existing message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<u32>UID (or sequence number) of this message, or None if this is a
dummy parent (RFC 5256 Section 4).
children: Vec<Self>Child thread nodes (RFC 5256 Section 4).